==> qtjambi-remoteobjects-debuginfo-macos-5.15.17.jar: sources/QtJambiRemoteObjects/QtRemoteObjects_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtRemoteObjects/qtremoteobjectglobal.h>
#include <QtCore/QVariant>
#include "utils_p.h"
#include <QtRemoteObjects/private/qconnectionfactories_p.h>
#include <QtCore/qdatastream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QtRemoteObjects::copyStoredProperties<_jobject>(QDataStream&,_jobject*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QtRemoteObjects_copyStoredProperties_1native_1ref_1QDataStream_1_1jobject_1ptr__Ljava_lang_Class_2JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jclass,
 jclass type,
 QtJambiNativeID src0,
 jobject dst1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtRemoteObjects::copyStoredProperties<_jobject>(QDataStream&,_jobject*)")
    QTJAMBI_TRY {
        QDataStream& __qt_src0 = QtJambiAPI::objectReferenceFromNativeId<QDataStream>(__jni_env, src0);
        qtjambi_copyStoredProperties(__jni_env, type, __qt_src0, dst1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtRemoteObjects::copyStoredProperties<_jobject>(const _jobject*,QDataStream&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QtRemoteObjects_copyStoredProperties_1native_1const_1_1jobject_1ptr_1ref_1QDataStream__Ljava_lang_Class_2Ljava_lang_Object_2J)
(JNIEnv *__jni_env,
 jclass,
 jclass type,
 jobject src0,
 QtJambiNativeID dst1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtRemoteObjects::copyStoredProperties<_jobject>(const _jobject*,QDataStream&)")
    QTJAMBI_TRY {
        QDataStream& __qt_dst1 = QtJambiAPI::objectReferenceFromNativeId<QDataStream>(__jni_env, dst1);
        qtjambi_copyStoredProperties(__jni_env, type, src0, __qt_dst1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtRemoteObjects::copyStoredProperties<_jobject>(const _jobject*,_jobject*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QtRemoteObjects_copyStoredProperties__Ljava_lang_Class_2Ljava_lang_Object_2Ljava_lang_Object_2)
(JNIEnv *__jni_env,
 jclass,
 jclass type,
 jobject src0,
 jobject dst1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtRemoteObjects::copyStoredProperties<_jobject>(const _jobject*,_jobject*)")
    QTJAMBI_TRY {
        qtjambi_copyStoredProperties(__jni_env, type, src0, dst1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtRemoteObjects::qRegisterRemoteObjectsClient<char>(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QtRemoteObjects_qRegisterRemoteObjectsClient__Ljava_lang_String_2Ljava_lang_Class_2)
(JNIEnv *__jni_env,
 jclass,
 jstring id0,
 jclass type)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtRemoteObjects::qRegisterRemoteObjectsClient<char>(QString)")
    QTJAMBI_TRY {
        QString  __qt_id0 = qtjambi_cast<QString >(__jni_env, id0);
        qtjambi_qRegisterRemoteObjectsClient(__jni_env, type, __qt_id0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtRemoteObjects::qRegisterRemoteObjectsServer<char>(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QtRemoteObjects_qRegisterRemoteObjectsServer__Ljava_lang_String_2Ljava_lang_Class_2)
(JNIEnv *__jni_env,
 jclass,
 jstring id0,
 jclass type)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtRemoteObjects::qRegisterRemoteObjectsServer<char>(QString)")
    QTJAMBI_TRY {
        QString  __qt_id0 = qtjambi_cast<QString >(__jni_env, id0);
        qtjambi_qRegisterRemoteObjectsServer(__jni_env, type, __qt_id0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QtRemoteObjects(){
    using namespace RegistryAPI;
    registerNamespaceTypeInfo("QtRemoteObjects", "io/qt/remoteobjects/QtRemoteObjects", nullptr);

// BEGIN: enums and flags
    registerEnumTypeInfoNoMetaObject<QtRemoteObjects::InitialAction>("QtRemoteObjects::InitialAction", "io/qt/remoteobjects/QtRemoteObjects$InitialAction");
    registerEnumTypeInfoNoMetaObject<QtRemoteObjects::QRemoteObjectPacketTypeEnum>("QtRemoteObjects::QRemoteObjectPacketTypeEnum", "io/qt/remoteobjects/QtRemoteObjects$QRemoteObjectPacketTypeEnum");
// END: enums and flags
}

==> qtjambi-remoteobjects-debuginfo-macos-6.5.4.jar: sources/QtJambiRemoteObjects/QtRemoteObjects_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtRemoteObjects/qtremoteobjectglobal.h>
#include <QtCore/QVariant>
#include <QtCore/qdatastream.h>
#include <QtRemoteObjects/qconnectionfactories.h>
#include "utils_p.h"

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QtRemoteObjects::copyStoredProperties<_jobject>(QDataStream&,_jobject*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QtRemoteObjects_copyStoredProperties_1native_1ref_1QDataStream_1_1jobject_1ptr__Ljava_lang_Class_2JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jclass,
 jclass type,
 QtJambiNativeID src0,
 jobject dst1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtRemoteObjects::copyStoredProperties<_jobject>(QDataStream&,_jobject*)")
    QTJAMBI_TRY {
        QDataStream& __qt_src0 = QtJambiAPI::objectReferenceFromNativeId<QDataStream>(__jni_env, src0);
        qtjambi_copyStoredProperties(__jni_env, type, __qt_src0, dst1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtRemoteObjects::copyStoredProperties<_jobject>(const _jobject*,QDataStream&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QtRemoteObjects_copyStoredProperties_1native_1const_1_1jobject_1ptr_1ref_1QDataStream__Ljava_lang_Class_2Ljava_lang_Object_2J)
(JNIEnv *__jni_env,
 jclass,
 jclass type,
 jobject src0,
 QtJambiNativeID dst1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtRemoteObjects::copyStoredProperties<_jobject>(const _jobject*,QDataStream&)")
    QTJAMBI_TRY {
        QDataStream& __qt_dst1 = QtJambiAPI::objectReferenceFromNativeId<QDataStream>(__jni_env, dst1);
        qtjambi_copyStoredProperties(__jni_env, type, src0, __qt_dst1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtRemoteObjects::copyStoredProperties<_jobject>(const _jobject*,_jobject*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QtRemoteObjects_copyStoredProperties__Ljava_lang_Class_2Ljava_lang_Object_2Ljava_lang_Object_2)
(JNIEnv *__jni_env,
 jclass,
 jclass type,
 jobject src0,
 jobject dst1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtRemoteObjects::copyStoredProperties<_jobject>(const _jobject*,_jobject*)")
    QTJAMBI_TRY {
        qtjambi_copyStoredProperties(__jni_env, type, src0, dst1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtRemoteObjects::qRegisterRemoteObjectsClient<char>(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QtRemoteObjects_qRegisterRemoteObjectsClient__Ljava_lang_String_2Ljava_lang_Class_2)
(JNIEnv *__jni_env,
 jclass,
 jstring id0,
 jclass type)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtRemoteObjects::qRegisterRemoteObjectsClient<char>(QString)")
    QTJAMBI_TRY {
        QString  __qt_id0 = qtjambi_cast<QString>(__jni_env, id0);
        qtjambi_qRegisterRemoteObjectsClient(__jni_env, type, __qt_id0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QtRemoteObjects::qRegisterRemoteObjectsServer<char>(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_remoteobjects_QtRemoteObjects_qRegisterRemoteObjectsServer__Ljava_lang_String_2Ljava_lang_Class_2)
(JNIEnv *__jni_env,
 jclass,
 jstring id0,
 jclass type)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtRemoteObjects::qRegisterRemoteObjectsServer<char>(QString)")
    QTJAMBI_TRY {
        QString  __qt_id0 = qtjambi_cast<QString>(__jni_env, id0);
        qtjambi_qRegisterRemoteObjectsServer(__jni_env, type, __qt_id0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QtRemoteObjects(){
    using namespace RegistryAPI;
    registerNamespaceTypeInfo("QtRemoteObjects", "io/qt/remoteobjects/QtRemoteObjects", nullptr);

// BEGIN: enums and flags
    registerEnumTypeInfoNoMetaObject<QtRemoteObjects::InitialAction>("QtRemoteObjects::InitialAction", "io/qt/remoteobjects/QtRemoteObjects$InitialAction");
    registerEnumTypeInfoNoMetaObject<QtRemoteObjects::QRemoteObjectPacketTypeEnum>("QtRemoteObjects::QRemoteObjectPacketTypeEnum", "io/qt/remoteobjects/QtRemoteObjects$QRemoteObjectPacketTypeEnum");
// END: enums and flags
}
